# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SessionActivityEntryAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bytes_transferred': 'int',
        'created': 'str',
        'duration': 'int',
        'file_name': 'str',
        'file_source': 'str',
        'ip_address': 'str',
        'operation': 'str',
        'protocol': 'str',
        'session_id': 'str',
        'status': 'str',
        'username': 'str'
    }

    attribute_map = {
        'bytes_transferred': 'bytesTransferred',
        'created': 'created',
        'duration': 'duration',
        'file_name': 'fileName',
        'file_source': 'fileSource',
        'ip_address': 'ipAddress',
        'operation': 'operation',
        'protocol': 'protocol',
        'session_id': 'sessionId',
        'status': 'status',
        'username': 'username'
    }

    def __init__(self, bytes_transferred=None, created=None, duration=None, file_name=None, file_source=None, ip_address=None, operation=None, protocol=None, session_id=None, status=None, username=None):  # noqa: E501
        """SessionActivityEntryAttributes - a model defined in Swagger"""  # noqa: E501
        self._bytes_transferred = None
        self._created = None
        self._duration = None
        self._file_name = None
        self._file_source = None
        self._ip_address = None
        self._operation = None
        self._protocol = None
        self._session_id = None
        self._status = None
        self._username = None
        self.discriminator = None
        if bytes_transferred is not None:
            self.bytes_transferred = bytes_transferred
        if created is not None:
            self.created = created
        if duration is not None:
            self.duration = duration
        if file_name is not None:
            self.file_name = file_name
        if file_source is not None:
            self.file_source = file_source
        if ip_address is not None:
            self.ip_address = ip_address
        if operation is not None:
            self.operation = operation
        if protocol is not None:
            self.protocol = protocol
        if session_id is not None:
            self.session_id = session_id
        if status is not None:
            self.status = status
        if username is not None:
            self.username = username

    @property
    def bytes_transferred(self):
        """Gets the bytes_transferred of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The bytes_transferred of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: int
        """
        return self._bytes_transferred

    @bytes_transferred.setter
    def bytes_transferred(self, bytes_transferred):
        """Sets the bytes_transferred of this SessionActivityEntryAttributes.


        :param bytes_transferred: The bytes_transferred of this SessionActivityEntryAttributes.  # noqa: E501
        :type: int
        """

        self._bytes_transferred = bytes_transferred

    @property
    def created(self):
        """Gets the created of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The created of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this SessionActivityEntryAttributes.


        :param created: The created of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def duration(self):
        """Gets the duration of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The duration of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this SessionActivityEntryAttributes.


        :param duration: The duration of this SessionActivityEntryAttributes.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def file_name(self):
        """Gets the file_name of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The file_name of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this SessionActivityEntryAttributes.


        :param file_name: The file_name of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def file_source(self):
        """Gets the file_source of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The file_source of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._file_source

    @file_source.setter
    def file_source(self, file_source):
        """Sets the file_source of this SessionActivityEntryAttributes.


        :param file_source: The file_source of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._file_source = file_source

    @property
    def ip_address(self):
        """Gets the ip_address of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The ip_address of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this SessionActivityEntryAttributes.


        :param ip_address: The ip_address of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def operation(self):
        """Gets the operation of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The operation of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this SessionActivityEntryAttributes.


        :param operation: The operation of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def protocol(self):
        """Gets the protocol of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The protocol of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this SessionActivityEntryAttributes.


        :param protocol: The protocol of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._protocol = protocol

    @property
    def session_id(self):
        """Gets the session_id of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The session_id of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this SessionActivityEntryAttributes.


        :param session_id: The session_id of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def status(self):
        """Gets the status of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The status of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SessionActivityEntryAttributes.


        :param status: The status of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def username(self):
        """Gets the username of this SessionActivityEntryAttributes.  # noqa: E501


        :return: The username of this SessionActivityEntryAttributes.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this SessionActivityEntryAttributes.


        :param username: The username of this SessionActivityEntryAttributes.  # noqa: E501
        :type: str
        """

        self._username = username

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SessionActivityEntryAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SessionActivityEntryAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateShareRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'resources': 'list[str]',
        'access_mode': 'AccessMode',
        'embed': 'bool',
        'recipients': 'list[SharesRecipients]',
        'expiration': 'datetime',
        'has_notification': 'bool',
        'is_public': 'bool',
        'message_body': 'str',
        'notification_emails': 'list[str]',
        'password': 'str',
        'require_email': 'bool',
        'message_subject': 'str',
        'file_drop_create_folders': 'bool',
        'status': 'int'
    }

    attribute_map = {
        'name': 'name',
        'resources': 'resources',
        'access_mode': 'accessMode',
        'embed': 'embed',
        'recipients': 'recipients',
        'expiration': 'expiration',
        'has_notification': 'hasNotification',
        'is_public': 'isPublic',
        'message_body': 'messageBody',
        'notification_emails': 'notificationEmails',
        'password': 'password',
        'require_email': 'requireEmail',
        'message_subject': 'messageSubject',
        'file_drop_create_folders': 'fileDropCreateFolders',
        'status': 'status'
    }

    def __init__(self, name=None, resources=None, access_mode=None, embed=None, recipients=None, expiration=None, has_notification=None, is_public=None, message_body=None, notification_emails=None, password=None, require_email=None, message_subject=None, file_drop_create_folders=None, status=None):  # noqa: E501
        """UpdateShareRequestBody - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._resources = None
        self._access_mode = None
        self._embed = None
        self._recipients = None
        self._expiration = None
        self._has_notification = None
        self._is_public = None
        self._message_body = None
        self._notification_emails = None
        self._password = None
        self._require_email = None
        self._message_subject = None
        self._file_drop_create_folders = None
        self._status = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if resources is not None:
            self.resources = resources
        if access_mode is not None:
            self.access_mode = access_mode
        if embed is not None:
            self.embed = embed
        if recipients is not None:
            self.recipients = recipients
        if expiration is not None:
            self.expiration = expiration
        if has_notification is not None:
            self.has_notification = has_notification
        if is_public is not None:
            self.is_public = is_public
        if message_body is not None:
            self.message_body = message_body
        if notification_emails is not None:
            self.notification_emails = notification_emails
        if password is not None:
            self.password = password
        if require_email is not None:
            self.require_email = require_email
        if message_subject is not None:
            self.message_subject = message_subject
        if file_drop_create_folders is not None:
            self.file_drop_create_folders = file_drop_create_folders
        if status is not None:
            self.status = status

    @property
    def name(self):
        """Gets the name of this UpdateShareRequestBody.  # noqa: E501

        Name of the share.  # noqa: E501

        :return: The name of this UpdateShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateShareRequestBody.

        Name of the share.  # noqa: E501

        :param name: The name of this UpdateShareRequestBody.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def resources(self):
        """Gets the resources of this UpdateShareRequestBody.  # noqa: E501

        Array of resources for this share. See details on [how to specify resources](#section/Identifying-Resources) above.  **shared_folder** and **receive** shares must have only one `resource`, which is a directory that does not have a current share attached.  **send** shares may have multiple `resource` parameters.   **NOTE**: Sending this parameter will **REPLACE** the existing resources with the resources included in this request.  # noqa: E501

        :return: The resources of this UpdateShareRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this UpdateShareRequestBody.

        Array of resources for this share. See details on [how to specify resources](#section/Identifying-Resources) above.  **shared_folder** and **receive** shares must have only one `resource`, which is a directory that does not have a current share attached.  **send** shares may have multiple `resource` parameters.   **NOTE**: Sending this parameter will **REPLACE** the existing resources with the resources included in this request.  # noqa: E501

        :param resources: The resources of this UpdateShareRequestBody.  # noqa: E501
        :type: list[str]
        """

        self._resources = resources

    @property
    def access_mode(self):
        """Gets the access_mode of this UpdateShareRequestBody.  # noqa: E501


        :return: The access_mode of this UpdateShareRequestBody.  # noqa: E501
        :rtype: AccessMode
        """
        return self._access_mode

    @access_mode.setter
    def access_mode(self, access_mode):
        """Sets the access_mode of this UpdateShareRequestBody.


        :param access_mode: The access_mode of this UpdateShareRequestBody.  # noqa: E501
        :type: AccessMode
        """

        self._access_mode = access_mode

    @property
    def embed(self):
        """Gets the embed of this UpdateShareRequestBody.  # noqa: E501

        Whether the share can be embedded in another web page.  # noqa: E501

        :return: The embed of this UpdateShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._embed

    @embed.setter
    def embed(self, embed):
        """Sets the embed of this UpdateShareRequestBody.

        Whether the share can be embedded in another web page.  # noqa: E501

        :param embed: The embed of this UpdateShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._embed = embed

    @property
    def recipients(self):
        """Gets the recipients of this UpdateShareRequestBody.  # noqa: E501

        People you want to invite to the share.   **Note**: unless you also set the `subject` and `message` for the new share, invitation emails will not be sent to these recipients.  **Note**: Recipients in this list will **REPLACE** the recipients already assigned to this share.   # noqa: E501

        :return: The recipients of this UpdateShareRequestBody.  # noqa: E501
        :rtype: list[SharesRecipients]
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this UpdateShareRequestBody.

        People you want to invite to the share.   **Note**: unless you also set the `subject` and `message` for the new share, invitation emails will not be sent to these recipients.  **Note**: Recipients in this list will **REPLACE** the recipients already assigned to this share.   # noqa: E501

        :param recipients: The recipients of this UpdateShareRequestBody.  # noqa: E501
        :type: list[SharesRecipients]
        """

        self._recipients = recipients

    @property
    def expiration(self):
        """Gets the expiration of this UpdateShareRequestBody.  # noqa: E501

        New expiration date and time for the share  # noqa: E501

        :return: The expiration of this UpdateShareRequestBody.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this UpdateShareRequestBody.

        New expiration date and time for the share  # noqa: E501

        :param expiration: The expiration of this UpdateShareRequestBody.  # noqa: E501
        :type: datetime
        """

        self._expiration = expiration

    @property
    def has_notification(self):
        """Gets the has_notification of this UpdateShareRequestBody.  # noqa: E501

        Whether delivery receipts should be sent for this share.  # noqa: E501

        :return: The has_notification of this UpdateShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._has_notification

    @has_notification.setter
    def has_notification(self, has_notification):
        """Sets the has_notification of this UpdateShareRequestBody.

        Whether delivery receipts should be sent for this share.  # noqa: E501

        :param has_notification: The has_notification of this UpdateShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._has_notification = has_notification

    @property
    def is_public(self):
        """Gets the is_public of this UpdateShareRequestBody.  # noqa: E501

        Whether people can visit the share without following a link from an invitation email  # noqa: E501

        :return: The is_public of this UpdateShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this UpdateShareRequestBody.

        Whether people can visit the share without following a link from an invitation email  # noqa: E501

        :param is_public: The is_public of this UpdateShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def message_body(self):
        """Gets the message_body of this UpdateShareRequestBody.  # noqa: E501

        Message content to use for emails inviting recipients to the share. Ignored if you have not also provided `recipients` and a `subject`  # noqa: E501

        :return: The message_body of this UpdateShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._message_body

    @message_body.setter
    def message_body(self, message_body):
        """Sets the message_body of this UpdateShareRequestBody.

        Message content to use for emails inviting recipients to the share. Ignored if you have not also provided `recipients` and a `subject`  # noqa: E501

        :param message_body: The message_body of this UpdateShareRequestBody.  # noqa: E501
        :type: str
        """

        self._message_body = message_body

    @property
    def notification_emails(self):
        """Gets the notification_emails of this UpdateShareRequestBody.  # noqa: E501

        List of email addresses to send delivery receipts to. Ignored if `hasNotification` is false.   # noqa: E501

        :return: The notification_emails of this UpdateShareRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._notification_emails

    @notification_emails.setter
    def notification_emails(self, notification_emails):
        """Sets the notification_emails of this UpdateShareRequestBody.

        List of email addresses to send delivery receipts to. Ignored if `hasNotification` is false.   # noqa: E501

        :param notification_emails: The notification_emails of this UpdateShareRequestBody.  # noqa: E501
        :type: list[str]
        """

        self._notification_emails = notification_emails

    @property
    def password(self):
        """Gets the password of this UpdateShareRequestBody.  # noqa: E501

        New password for the share. To leave the password unchanged, do not send this parameter.  # noqa: E501

        :return: The password of this UpdateShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateShareRequestBody.

        New password for the share. To leave the password unchanged, do not send this parameter.  # noqa: E501

        :param password: The password of this UpdateShareRequestBody.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def require_email(self):
        """Gets the require_email of this UpdateShareRequestBody.  # noqa: E501

        Whether visitors to the share will be required to enter their email in order to access the share.  # noqa: E501

        :return: The require_email of this UpdateShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._require_email

    @require_email.setter
    def require_email(self, require_email):
        """Sets the require_email of this UpdateShareRequestBody.

        Whether visitors to the share will be required to enter their email in order to access the share.  # noqa: E501

        :param require_email: The require_email of this UpdateShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._require_email = require_email

    @property
    def message_subject(self):
        """Gets the message_subject of this UpdateShareRequestBody.  # noqa: E501

        Subject to use on emails inviting recipients to the share. Ignored if you have not also provided `recipients` and a `message`  # noqa: E501

        :return: The message_subject of this UpdateShareRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._message_subject

    @message_subject.setter
    def message_subject(self, message_subject):
        """Sets the message_subject of this UpdateShareRequestBody.

        Subject to use on emails inviting recipients to the share. Ignored if you have not also provided `recipients` and a `message`  # noqa: E501

        :param message_subject: The message_subject of this UpdateShareRequestBody.  # noqa: E501
        :type: str
        """

        self._message_subject = message_subject

    @property
    def file_drop_create_folders(self):
        """Gets the file_drop_create_folders of this UpdateShareRequestBody.  # noqa: E501

        Whether uploads to a receive folder should be automatically placed into subfolders. See our [receive folder documentation](/docs/account/05-file-sharing/05-form-builder#advanced-form-settings)  # noqa: E501

        :return: The file_drop_create_folders of this UpdateShareRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._file_drop_create_folders

    @file_drop_create_folders.setter
    def file_drop_create_folders(self, file_drop_create_folders):
        """Sets the file_drop_create_folders of this UpdateShareRequestBody.

        Whether uploads to a receive folder should be automatically placed into subfolders. See our [receive folder documentation](/docs/account/05-file-sharing/05-form-builder#advanced-form-settings)  # noqa: E501

        :param file_drop_create_folders: The file_drop_create_folders of this UpdateShareRequestBody.  # noqa: E501
        :type: bool
        """

        self._file_drop_create_folders = file_drop_create_folders

    @property
    def status(self):
        """Gets the status of this UpdateShareRequestBody.  # noqa: E501

        New status for the share. You can set an active share to inactive by setting the status to **0**  # noqa: E501

        :return: The status of this UpdateShareRequestBody.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this UpdateShareRequestBody.

        New status for the share. You can set an active share to inactive by setting the status to **0**  # noqa: E501

        :param status: The status of this UpdateShareRequestBody.  # noqa: E501
        :type: int
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateShareRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateShareRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AddUserRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'username': 'str',
        'nickname': 'str',
        'home_resource': 'str',
        'email': 'str',
        'password': 'str',
        'role': 'str',
        'permissions': 'UsersPermissions',
        'time_zone': 'str',
        'expiration': 'str',
        'locked': 'bool',
        'welcome_email': 'bool',
        'onboarding': 'bool'
    }

    attribute_map = {
        'username': 'username',
        'nickname': 'nickname',
        'home_resource': 'homeResource',
        'email': 'email',
        'password': 'password',
        'role': 'role',
        'permissions': 'permissions',
        'time_zone': 'timeZone',
        'expiration': 'expiration',
        'locked': 'locked',
        'welcome_email': 'welcomeEmail',
        'onboarding': 'onboarding'
    }

    def __init__(self, username=None, nickname=None, home_resource=None, email=None, password=None, role=None, permissions=None, time_zone=None, expiration=None, locked=None, welcome_email=None, onboarding=None):  # noqa: E501
        """AddUserRequestBody - a model defined in Swagger"""  # noqa: E501
        self._username = None
        self._nickname = None
        self._home_resource = None
        self._email = None
        self._password = None
        self._role = None
        self._permissions = None
        self._time_zone = None
        self._expiration = None
        self._locked = None
        self._welcome_email = None
        self._onboarding = None
        self.discriminator = None
        self.username = username
        if nickname is not None:
            self.nickname = nickname
        self.home_resource = home_resource
        self.email = email
        self.password = password
        self.role = role
        self.permissions = permissions
        self.time_zone = time_zone
        if expiration is not None:
            self.expiration = expiration
        if locked is not None:
            self.locked = locked
        if welcome_email is not None:
            self.welcome_email = welcome_email
        if onboarding is not None:
            self.onboarding = onboarding

    @property
    def username(self):
        """Gets the username of this AddUserRequestBody.  # noqa: E501

        Username of the user to create. This should follow standard username conventions - spaces are not allowed, etc. We do allow email addresses as usernames.  **Note** Usernames must be unique across all ExaVault accounts.  # noqa: E501

        :return: The username of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AddUserRequestBody.

        Username of the user to create. This should follow standard username conventions - spaces are not allowed, etc. We do allow email addresses as usernames.  **Note** Usernames must be unique across all ExaVault accounts.  # noqa: E501

        :param username: The username of this AddUserRequestBody.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def nickname(self):
        """Gets the nickname of this AddUserRequestBody.  # noqa: E501

        An optional nickname (e.g. 'David from Sales').  # noqa: E501

        :return: The nickname of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """Sets the nickname of this AddUserRequestBody.

        An optional nickname (e.g. 'David from Sales').  # noqa: E501

        :param nickname: The nickname of this AddUserRequestBody.  # noqa: E501
        :type: str
        """

        self._nickname = nickname

    @property
    def home_resource(self):
        """Gets the home_resource of this AddUserRequestBody.  # noqa: E501

        Resource identifier for the user's home folder. See details on [how to specify resources](#section/Identifying-Resources) above.  The user will be locked to this directory and unable to move 'up' in the account. If the folder does not exist in the account, it will be created when the user is created.   This setting is ignored for users with the `role` **admin**.  # noqa: E501

        :return: The home_resource of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._home_resource

    @home_resource.setter
    def home_resource(self, home_resource):
        """Sets the home_resource of this AddUserRequestBody.

        Resource identifier for the user's home folder. See details on [how to specify resources](#section/Identifying-Resources) above.  The user will be locked to this directory and unable to move 'up' in the account. If the folder does not exist in the account, it will be created when the user is created.   This setting is ignored for users with the `role` **admin**.  # noqa: E501

        :param home_resource: The home_resource of this AddUserRequestBody.  # noqa: E501
        :type: str
        """
        if home_resource is None:
            raise ValueError("Invalid value for `home_resource`, must not be `None`")  # noqa: E501

        self._home_resource = home_resource

    @property
    def email(self):
        """Gets the email of this AddUserRequestBody.  # noqa: E501

        Email address for the user  # noqa: E501

        :return: The email of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AddUserRequestBody.

        Email address for the user  # noqa: E501

        :param email: The email of this AddUserRequestBody.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def password(self):
        """Gets the password of this AddUserRequestBody.  # noqa: E501

        Password for the user  # noqa: E501

        :return: The password of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this AddUserRequestBody.

        Password for the user  # noqa: E501

        :param password: The password of this AddUserRequestBody.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def role(self):
        """Gets the role of this AddUserRequestBody.  # noqa: E501

        The type of user to create. Note that admin users cannot have a `homeResource` other than '/', and will have full permissions, but you must provide at least \"download,upload,list,delete\" in the `permissions` parameter.  # noqa: E501

        :return: The role of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this AddUserRequestBody.

        The type of user to create. Note that admin users cannot have a `homeResource` other than '/', and will have full permissions, but you must provide at least \"download,upload,list,delete\" in the `permissions` parameter.  # noqa: E501

        :param role: The role of this AddUserRequestBody.  # noqa: E501
        :type: str
        """
        if role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["user", "admin"]  # noqa: E501
        if role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    @property
    def permissions(self):
        """Gets the permissions of this AddUserRequestBody.  # noqa: E501


        :return: The permissions of this AddUserRequestBody.  # noqa: E501
        :rtype: UsersPermissions
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this AddUserRequestBody.


        :param permissions: The permissions of this AddUserRequestBody.  # noqa: E501
        :type: UsersPermissions
        """
        if permissions is None:
            raise ValueError("Invalid value for `permissions`, must not be `None`")  # noqa: E501

        self._permissions = permissions

    @property
    def time_zone(self):
        """Gets the time_zone of this AddUserRequestBody.  # noqa: E501

        Time zone, used for accurate time display within the application. See <a href='https://php.net/manual/en/timezones.php' target='blank'>this page</a> for allowed values.   # noqa: E501

        :return: The time_zone of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this AddUserRequestBody.

        Time zone, used for accurate time display within the application. See <a href='https://php.net/manual/en/timezones.php' target='blank'>this page</a> for allowed values.   # noqa: E501

        :param time_zone: The time_zone of this AddUserRequestBody.  # noqa: E501
        :type: str
        """
        if time_zone is None:
            raise ValueError("Invalid value for `time_zone`, must not be `None`")  # noqa: E501

        self._time_zone = time_zone

    @property
    def expiration(self):
        """Gets the expiration of this AddUserRequestBody.  # noqa: E501

        Optional timestamp when the user should expire, formatted in date-time.  # noqa: E501

        :return: The expiration of this AddUserRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this AddUserRequestBody.

        Optional timestamp when the user should expire, formatted in date-time.  # noqa: E501

        :param expiration: The expiration of this AddUserRequestBody.  # noqa: E501
        :type: str
        """

        self._expiration = expiration

    @property
    def locked(self):
        """Gets the locked of this AddUserRequestBody.  # noqa: E501

        If true, the user will not be able to log in  # noqa: E501

        :return: The locked of this AddUserRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this AddUserRequestBody.

        If true, the user will not be able to log in  # noqa: E501

        :param locked: The locked of this AddUserRequestBody.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def welcome_email(self):
        """Gets the welcome_email of this AddUserRequestBody.  # noqa: E501

        If **true**, send this new user a welcome email upon creation. The content of the welcome email can be configured with the [PATCH /accounts](#operation/updateAccount) method.  # noqa: E501

        :return: The welcome_email of this AddUserRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._welcome_email

    @welcome_email.setter
    def welcome_email(self, welcome_email):
        """Sets the welcome_email of this AddUserRequestBody.

        If **true**, send this new user a welcome email upon creation. The content of the welcome email can be configured with the [PATCH /accounts](#operation/updateAccount) method.  # noqa: E501

        :param welcome_email: The welcome_email of this AddUserRequestBody.  # noqa: E501
        :type: bool
        """

        self._welcome_email = welcome_email

    @property
    def onboarding(self):
        """Gets the onboarding of this AddUserRequestBody.  # noqa: E501

        Set this to **true** to enable extra help popups in the web file manager for this user.  # noqa: E501

        :return: The onboarding of this AddUserRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._onboarding

    @onboarding.setter
    def onboarding(self, onboarding):
        """Sets the onboarding of this AddUserRequestBody.

        Set this to **true** to enable extra help popups in the web file manager for this user.  # noqa: E501

        :param onboarding: The onboarding of this AddUserRequestBody.  # noqa: E501
        :type: bool
        """

        self._onboarding = onboarding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AddUserRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddUserRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from exavault.api_client import ApiClient


class SharesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_share(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Creates a share  # noqa: E501

        Creates a new share object for the given path in your account. We support three types of shares:    - A **shared folder** allows you to let outside parties access a folder in your account (including any files and nested subfolders) using just a link. Shared folders can be restricted; e.g. with an expiration date, password, download-only, etc. Shared folders are 'live'; if someone makes a change to a file in your shared folder, it will be immediately reflected in your account, and vice-versa.   - A file **send** lets you send one or more files via an easy download link. File sends are different than shared folders because file sends are 'point in time' -- the recipient will get the files as you sent them. If you later make a change to the source file, it will not be updated for the recipient.   - A **receive** folder lets you receive files into your account. You can either send users a link, or optionally [embed a customized form](/docs/account/05-file-sharing/05-upload-widget) on your website.    **How to send files from your computer using the API**:  In order to use the API to send files which are not already stored in your account, you'll need to follow a three-step process:  1. Use the [POST /shares](#operation/addShare) endpoint to set up your send, including password, recipients, expiration, etc. You must include **upload** among the permissions in the `accessMode` and set the `sendingLocalFiles` parameter to **true**. The response that is returned will include a \"meta\" attribute, which contains an **accessToken** attribute. This new access token is valid only for the send. 2. Use the [POST /resources/upload](#operation/uploadFile) endpoint to upload your files to the send you've created. The \"/\" path represents the root of the share, not your home directory. **You must send the access token that you received from the first step in the `ev-access-token` header** 3. Use the [POST /shares/complete-send/{id}](#operation/completeDirectSend) endpoint to indicate that you have finished uploading files to your send. This will trigger the system to remove the **upload** permission from the share and send any invitation emails you set up in the first step of the process. **You must send YOUR access token in the `ev-access-token` header, not the temporary access token**  **Notes:**  Authenticated user requires [share permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_share(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddShareRequestBody body:
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_share_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.add_share_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def add_share_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Creates a share  # noqa: E501

        Creates a new share object for the given path in your account. We support three types of shares:    - A **shared folder** allows you to let outside parties access a folder in your account (including any files and nested subfolders) using just a link. Shared folders can be restricted; e.g. with an expiration date, password, download-only, etc. Shared folders are 'live'; if someone makes a change to a file in your shared folder, it will be immediately reflected in your account, and vice-versa.   - A file **send** lets you send one or more files via an easy download link. File sends are different than shared folders because file sends are 'point in time' -- the recipient will get the files as you sent them. If you later make a change to the source file, it will not be updated for the recipient.   - A **receive** folder lets you receive files into your account. You can either send users a link, or optionally [embed a customized form](/docs/account/05-file-sharing/05-upload-widget) on your website.    **How to send files from your computer using the API**:  In order to use the API to send files which are not already stored in your account, you'll need to follow a three-step process:  1. Use the [POST /shares](#operation/addShare) endpoint to set up your send, including password, recipients, expiration, etc. You must include **upload** among the permissions in the `accessMode` and set the `sendingLocalFiles` parameter to **true**. The response that is returned will include a \"meta\" attribute, which contains an **accessToken** attribute. This new access token is valid only for the send. 2. Use the [POST /resources/upload](#operation/uploadFile) endpoint to upload your files to the send you've created. The \"/\" path represents the root of the share, not your home directory. **You must send the access token that you received from the first step in the `ev-access-token` header** 3. Use the [POST /shares/complete-send/{id}](#operation/completeDirectSend) endpoint to indicate that you have finished uploading files to your send. This will trigger the system to remove the **upload** permission from the share and send any invitation emails you set up in the first step of the process. **You must send YOUR access token in the `ev-access-token` header, not the temporary access token**  **Notes:**  Authenticated user requires [share permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_share_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param AddShareRequestBody body:
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_share" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `add_share`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `add_share`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/shares', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ShareResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def complete_direct_send(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Complete send files  # noqa: E501

        After uploading the file(s) to be sent, this method will trigger invitation emails and finish the send files setup. If you are not sending files from your own computer in a send, you will not need this step.    **How to send files from your computer using the API**:  In order to use the API to send files which are not already stored in your account, you'll need to follow a three-step process:  1. Use the [POST /shares](#operation/addShare) endpoint to set up your send, including password, recipients, expiration, etc. You must include **upload** among the permissions in the `accessMode` and set the `sendingLocalFiles` paramter to **true**. The response that is returned will include a \"meta\" attribute, which contains an **accessToken** attribute. This new access token is valid only for the send. 2. Use the [POST /resources/upload](#operation/uploadFile) endpoint to upload your files to the send you've created. The \"/\" path represents the root of the share, not your home directory. **You must send the access token that you received from the first step in the `ev-access-token` header** 3. Use the [POST /shares/complete-send/{id}](#operation/completeDirectSend) endpoint to indicate that you have finished uploading files to your send. This will trigger the system to remove the **upload** permission from the share and send any invitation emails you set up in the first step of the process. **You must send YOUR access token in the `ev-access-token` header, not the temporary access token**   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.complete_direct_send(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param int id: ID of the share to trigger invitations for. (required)
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.complete_direct_send_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.complete_direct_send_with_http_info(ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def complete_direct_send_with_http_info(self, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Complete send files  # noqa: E501

        After uploading the file(s) to be sent, this method will trigger invitation emails and finish the send files setup. If you are not sending files from your own computer in a send, you will not need this step.    **How to send files from your computer using the API**:  In order to use the API to send files which are not already stored in your account, you'll need to follow a three-step process:  1. Use the [POST /shares](#operation/addShare) endpoint to set up your send, including password, recipients, expiration, etc. You must include **upload** among the permissions in the `accessMode` and set the `sendingLocalFiles` paramter to **true**. The response that is returned will include a \"meta\" attribute, which contains an **accessToken** attribute. This new access token is valid only for the send. 2. Use the [POST /resources/upload](#operation/uploadFile) endpoint to upload your files to the send you've created. The \"/\" path represents the root of the share, not your home directory. **You must send the access token that you received from the first step in the `ev-access-token` header** 3. Use the [POST /shares/complete-send/{id}](#operation/completeDirectSend) endpoint to indicate that you have finished uploading files to your send. This will trigger the system to remove the **upload** permission from the share and send any invitation emails you set up in the first step of the process. **You must send YOUR access token in the `ev-access-token` header, not the temporary access token**   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.complete_direct_send_with_http_info(ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param int id: ID of the share to trigger invitations for. (required)
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method complete_direct_send" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `complete_direct_send`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `complete_direct_send`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `complete_direct_send`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/shares/complete-send/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ShareResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_share_by_id(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Deactivate a share  # noqa: E501

        Deactivate a share. Deactivating a share does not remove the underlying files for **shared_folder** and **receive** share types; it merely removes the access URL. Deleting a **send** share type does remove the associated files, as files that have been sent are only associated with the share, and aren't stored anywhere else in the account.  **Notes:**  - You must have [sharing permissons](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to use this. - You must have [admin-level access](/docs/account/04-users/01-admin-users), or you must be the owner of the specified share you wish to delete.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_share_by_id(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: ID of the share entry (required)
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_share_by_id_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_share_by_id_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def delete_share_by_id_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Deactivate a share  # noqa: E501

        Deactivate a share. Deactivating a share does not remove the underlying files for **shared_folder** and **receive** share types; it merely removes the access URL. Deleting a **send** share type does remove the associated files, as files that have been sent are only associated with the share, and aren't stored anywhere else in the account.  **Notes:**  - You must have [sharing permissons](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions) to use this. - You must have [admin-level access](/docs/account/04-users/01-admin-users), or you must be the owner of the specified share you wish to delete.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_share_by_id_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: ID of the share entry (required)
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :return: EmptyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_share_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_share_by_id`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `delete_share_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `delete_share_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/shares/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmptyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_share_by_id(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get a share  # noqa: E501

        Get the details for a specific share entry. You can use the `include` parameter to also get the details of related records, such as the owning user or the resources involved in the share.  **Notes:**  - Authenticated user requires [share permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions). - To get share objects with type send, authenticated user's role must be admin or master.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_share_by_id(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: ID of the share entry (required)
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param str include: Comma separated list of relationships to include in response. Possible values are **owner**, **resources**, **notifications**, **activity**.
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_share_by_id_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_share_by_id_with_http_info(id, ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def get_share_by_id_with_http_info(self, id, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get a share  # noqa: E501

        Get the details for a specific share entry. You can use the `include` parameter to also get the details of related records, such as the owning user or the resources involved in the share.  **Notes:**  - Authenticated user requires [share permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions). - To get share objects with type send, authenticated user's role must be admin or master.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_share_by_id_with_http_info(id, ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: ID of the share entry (required)
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param str include: Comma separated list of relationships to include in response. Possible values are **owner**, **resources**, **notifications**, **activity**.
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'ev_api_key', 'ev_access_token', 'include']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_share_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_share_by_id`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `get_share_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `get_share_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/shares/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ShareResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_shares(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get a list of shares  # noqa: E501

        Get a list of shares that you would have access to view through the web interface. You can limit which results are returned by specifying specific types of shares you wish to view, finding things shared with a specific email address, as well as finding shares for specific folder names.   **Notes:**  - Authenticated user requires [share permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions). - To get share objects with type send, authenticated user's role must be admin or master.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_shares(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int offset: Current offset of records (for pagination)
        :param int limit: Limit of records to be returned (for pagination)
        :param str scope: Set of shares to return. (**all**=all of them, **active**=shares that are currently active, **curentUser**=shares created by you)
        :param str sort: What order the list of matches should be in.
        :param str type: Limit the list of matches to only certain types of shares.
        :param str include: Comma separated list of relationships to include in response. Possible values are **owner**, **resources**, **notifications**, **activity**.
        :param str name: When provided, only shares whose names include this value will be in the list. Supports wildcards, such as **send\\*** to return everything starting with \"send\".  Use this parameter if you are searching for shares or receives for a specific folder name. For example **/Clients/ACME/To Be Processed**.
        :param str recipient: Filter the results to include only shares that invited a certain email address. Supports wildcard matching so that **\\*@example.com** will give back entries shared with addresses ending in \"@example.com\". 
        :param str message: When provided, only shares with a message that contains the text will be included in the list of matches. Both the subject and the body of all messages will be checked for matches. This will always be a wildcard match, so that searching for **taxes** will return any shares with a message that contains the word \"taxes\".
        :param str username: When provided, only shares created by the user with that `username` will be included in the list. Does not support wildcard searching.
        :param str search: Searches the share name, username, recipients, share messages fields for the provided value. Supports wildcard searches.
        :return: ShareCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_shares_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
        else:
            (data) = self.list_shares_with_http_info(ev_api_key, ev_access_token, **kwargs)  # noqa: E501
            return data

    def list_shares_with_http_info(self, ev_api_key, ev_access_token, **kwargs):  # noqa: E501
        """Get a list of shares  # noqa: E501

        Get a list of shares that you would have access to view through the web interface. You can limit which results are returned by specifying specific types of shares you wish to view, finding things shared with a specific email address, as well as finding shares for specific folder names.   **Notes:**  - Authenticated user requires [share permission](/docs/account/04-users/00-introduction#managing-user-roles-and-permissions). - To get share objects with type send, authenticated user's role must be admin or master.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_shares_with_http_info(ev_api_key, ev_access_token, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str ev_api_key: API Key required to make the API call. (required)
        :param str ev_access_token: Access token required to make the API call. (required)
        :param int offset: Current offset of records (for pagination)
        :param int limit: Limit of records to be returned (for pagination)
        :param str scope: Set of shares to return. (**all**=all of them, **active**=shares that are currently active, **curentUser**=shares created by you)
        :param str sort: What order the list of matches should be in.
        :param str type: Limit the list of matches to only certain types of shares.
        :param str include: Comma separated list of relationships to include in response. Possible values are **owner**, **resources**, **notifications**, **activity**.
        :param str name: When provided, only shares whose names include this value will be in the list. Supports wildcards, such as **send\\*** to return everything starting with \"send\".  Use this parameter if you are searching for shares or receives for a specific folder name. For example **/Clients/ACME/To Be Processed**.
        :param str recipient: Filter the results to include only shares that invited a certain email address. Supports wildcard matching so that **\\*@example.com** will give back entries shared with addresses ending in \"@example.com\". 
        :param str message: When provided, only shares with a message that contains the text will be included in the list of matches. Both the subject and the body of all messages will be checked for matches. This will always be a wildcard match, so that searching for **taxes** will return any shares with a message that contains the word \"taxes\".
        :param str username: When provided, only shares created by the user with that `username` will be included in the list. Does not support wildcard searching.
        :param str search: Searches the share name, username, recipients, share messages fields for the provided value. Supports wildcard searches.
        :return: ShareCollectionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ev_api_key', 'ev_access_token', 'offset', 'limit', 'scope', 'sort', 'type', 'include', 'name', 'recipient', 'message', 'username', 'search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_shares" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `list_shares`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `list_shares`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'scope' in params:
            query_params.append(('scope', params['scope']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501
        if 'type' in params:
            query_params.append(('type', params['type']))  # noqa: E501
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501
        if 'recipient' in params:
            query_params.append(('recipient', params['recipient']))  # noqa: E501
        if 'message' in params:
            query_params.append(('message', params['message']))  # noqa: E501
        if 'username' in params:
            query_params.append(('username', params['username']))  # noqa: E501
        if 'search' in params:
            query_params.append(('search', params['search']))  # noqa: E501

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/shares', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ShareCollectionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_share_by_id(self, body, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update a share  # noqa: E501

        Change the settings on an active share. Any changes made will affect all users that have access to the share.   When updating invitees, pass the `recipients` body paramater with the full list of people who should be included on the share. If you resend the list without an existing recipient, they will be removed from the share.  **Notes:**    - Authenticated user should be the owner of the specified share.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_share_by_id(body, ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShareRequestBody body: (required)
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param int id: ID of the share entry (required)
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_share_by_id_with_http_info(body, ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_share_by_id_with_http_info(body, ev_api_key, ev_access_token, id, **kwargs)  # noqa: E501
            return data

    def update_share_by_id_with_http_info(self, body, ev_api_key, ev_access_token, id, **kwargs):  # noqa: E501
        """Update a share  # noqa: E501

        Change the settings on an active share. Any changes made will affect all users that have access to the share.   When updating invitees, pass the `recipients` body paramater with the full list of people who should be included on the share. If you resend the list without an existing recipient, they will be removed from the share.  **Notes:**    - Authenticated user should be the owner of the specified share.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_share_by_id_with_http_info(body, ev_api_key, ev_access_token, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateShareRequestBody body: (required)
        :param str ev_api_key: API Key (required)
        :param str ev_access_token: Access Token (required)
        :param int id: ID of the share entry (required)
        :return: ShareResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'ev_api_key', 'ev_access_token', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_share_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_share_by_id`")  # noqa: E501
        # verify the required parameter 'ev_api_key' is set
        if ('ev_api_key' not in params or
                params['ev_api_key'] is None):
            raise ValueError("Missing the required parameter `ev_api_key` when calling `update_share_by_id`")  # noqa: E501
        # verify the required parameter 'ev_access_token' is set
        if ('ev_access_token' not in params or
                params['ev_access_token'] is None):
            raise ValueError("Missing the required parameter `ev_access_token` when calling `update_share_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_share_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'ev_api_key' in params:
            header_params['ev-api-key'] = params['ev_api_key']  # noqa: E501
        if 'ev_access_token' in params:
            header_params['ev-access-token'] = params['ev_access_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/shares/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ShareResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FormAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'form_description': 'str',
        'submit_button_text': 'str',
        'success_message': 'str',
        'css_styles': 'str',
        'elements': 'list[FormField]'
    }

    attribute_map = {
        'form_description': 'formDescription',
        'submit_button_text': 'submitButtonText',
        'success_message': 'successMessage',
        'css_styles': 'cssStyles',
        'elements': 'elements'
    }

    def __init__(self, form_description=None, submit_button_text=None, success_message=None, css_styles=None, elements=None):  # noqa: E501
        """FormAttributes - a model defined in Swagger"""  # noqa: E501
        self._form_description = None
        self._submit_button_text = None
        self._success_message = None
        self._css_styles = None
        self._elements = None
        self.discriminator = None
        if form_description is not None:
            self.form_description = form_description
        if submit_button_text is not None:
            self.submit_button_text = submit_button_text
        if success_message is not None:
            self.success_message = success_message
        if css_styles is not None:
            self.css_styles = css_styles
        if elements is not None:
            self.elements = elements

    @property
    def form_description(self):
        """Gets the form_description of this FormAttributes.  # noqa: E501

        Text that appears at the top of a receive form  # noqa: E501

        :return: The form_description of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._form_description

    @form_description.setter
    def form_description(self, form_description):
        """Sets the form_description of this FormAttributes.

        Text that appears at the top of a receive form  # noqa: E501

        :param form_description: The form_description of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._form_description = form_description

    @property
    def submit_button_text(self):
        """Gets the submit_button_text of this FormAttributes.  # noqa: E501

        Text that appears on the submit button for the form  # noqa: E501

        :return: The submit_button_text of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._submit_button_text

    @submit_button_text.setter
    def submit_button_text(self, submit_button_text):
        """Sets the submit_button_text of this FormAttributes.

        Text that appears on the submit button for the form  # noqa: E501

        :param submit_button_text: The submit_button_text of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._submit_button_text = submit_button_text

    @property
    def success_message(self):
        """Gets the success_message of this FormAttributes.  # noqa: E501

        Message displayed to submitter after files are uploaded  # noqa: E501

        :return: The success_message of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._success_message

    @success_message.setter
    def success_message(self, success_message):
        """Sets the success_message of this FormAttributes.

        Message displayed to submitter after files are uploaded  # noqa: E501

        :param success_message: The success_message of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._success_message = success_message

    @property
    def css_styles(self):
        """Gets the css_styles of this FormAttributes.  # noqa: E501

        CSS Styles of the form.  # noqa: E501

        :return: The css_styles of this FormAttributes.  # noqa: E501
        :rtype: str
        """
        return self._css_styles

    @css_styles.setter
    def css_styles(self, css_styles):
        """Sets the css_styles of this FormAttributes.

        CSS Styles of the form.  # noqa: E501

        :param css_styles: The css_styles of this FormAttributes.  # noqa: E501
        :type: str
        """

        self._css_styles = css_styles

    @property
    def elements(self):
        """Gets the elements of this FormAttributes.  # noqa: E501

        Array of form fields defined for the form  # noqa: E501

        :return: The elements of this FormAttributes.  # noqa: E501
        :rtype: list[FormField]
        """
        return self._elements

    @elements.setter
    def elements(self, elements):
        """Sets the elements of this FormAttributes.

        Array of form fields defined for the form  # noqa: E501

        :param elements: The elements of this FormAttributes.  # noqa: E501
        :type: list[FormField]
        """

        self._elements = elements

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FormAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UsersPermissions(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'list': 'bool',
        'download': 'bool',
        'upload': 'bool',
        'modify': 'bool',
        'delete': 'bool',
        'change_password': 'bool',
        'share': 'bool',
        'notification': 'bool',
        'view_form_data': 'bool',
        'delete_form_data': 'bool'
    }

    attribute_map = {
        'list': 'list',
        'download': 'download',
        'upload': 'upload',
        'modify': 'modify',
        'delete': 'delete',
        'change_password': 'changePassword',
        'share': 'share',
        'notification': 'notification',
        'view_form_data': 'viewFormData',
        'delete_form_data': 'deleteFormData'
    }

    def __init__(self, list=None, download=None, upload=None, modify=None, delete=None, change_password=None, share=None, notification=None, view_form_data=None, delete_form_data=None):  # noqa: E501
        """UsersPermissions - a model defined in Swagger"""  # noqa: E501
        self._list = None
        self._download = None
        self._upload = None
        self._modify = None
        self._delete = None
        self._change_password = None
        self._share = None
        self._notification = None
        self._view_form_data = None
        self._delete_form_data = None
        self.discriminator = None
        if list is not None:
            self.list = list
        if download is not None:
            self.download = download
        if upload is not None:
            self.upload = upload
        if modify is not None:
            self.modify = modify
        if delete is not None:
            self.delete = delete
        if change_password is not None:
            self.change_password = change_password
        if share is not None:
            self.share = share
        if notification is not None:
            self.notification = notification
        if view_form_data is not None:
            self.view_form_data = view_form_data
        if delete_form_data is not None:
            self.delete_form_data = delete_form_data

    @property
    def list(self):
        """Gets the list of this UsersPermissions.  # noqa: E501


        :return: The list of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._list

    @list.setter
    def list(self, list):
        """Sets the list of this UsersPermissions.


        :param list: The list of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._list = list

    @property
    def download(self):
        """Gets the download of this UsersPermissions.  # noqa: E501


        :return: The download of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._download

    @download.setter
    def download(self, download):
        """Sets the download of this UsersPermissions.


        :param download: The download of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._download = download

    @property
    def upload(self):
        """Gets the upload of this UsersPermissions.  # noqa: E501


        :return: The upload of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._upload

    @upload.setter
    def upload(self, upload):
        """Sets the upload of this UsersPermissions.


        :param upload: The upload of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._upload = upload

    @property
    def modify(self):
        """Gets the modify of this UsersPermissions.  # noqa: E501


        :return: The modify of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._modify

    @modify.setter
    def modify(self, modify):
        """Sets the modify of this UsersPermissions.


        :param modify: The modify of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._modify = modify

    @property
    def delete(self):
        """Gets the delete of this UsersPermissions.  # noqa: E501


        :return: The delete of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """Sets the delete of this UsersPermissions.


        :param delete: The delete of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._delete = delete

    @property
    def change_password(self):
        """Gets the change_password of this UsersPermissions.  # noqa: E501


        :return: The change_password of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._change_password

    @change_password.setter
    def change_password(self, change_password):
        """Sets the change_password of this UsersPermissions.


        :param change_password: The change_password of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._change_password = change_password

    @property
    def share(self):
        """Gets the share of this UsersPermissions.  # noqa: E501


        :return: The share of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._share

    @share.setter
    def share(self, share):
        """Sets the share of this UsersPermissions.


        :param share: The share of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._share = share

    @property
    def notification(self):
        """Gets the notification of this UsersPermissions.  # noqa: E501


        :return: The notification of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        """Sets the notification of this UsersPermissions.


        :param notification: The notification of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._notification = notification

    @property
    def view_form_data(self):
        """Gets the view_form_data of this UsersPermissions.  # noqa: E501


        :return: The view_form_data of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._view_form_data

    @view_form_data.setter
    def view_form_data(self, view_form_data):
        """Sets the view_form_data of this UsersPermissions.


        :param view_form_data: The view_form_data of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._view_form_data = view_form_data

    @property
    def delete_form_data(self):
        """Gets the delete_form_data of this UsersPermissions.  # noqa: E501


        :return: The delete_form_data of this UsersPermissions.  # noqa: E501
        :rtype: bool
        """
        return self._delete_form_data

    @delete_form_data.setter
    def delete_form_data(self, delete_form_data):
        """Sets the delete_form_data of this UsersPermissions.


        :param delete_form_data: The delete_form_data of this UsersPermissions.  # noqa: E501
        :type: bool
        """

        self._delete_form_data = delete_form_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UsersPermissions, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UsersPermissions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AccountAttributes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_name': 'str',
        'username': 'str',
        'max_users': 'int',
        'user_count': 'int',
        'status': 'int',
        'branding': 'bool',
        'custom_domain': 'bool',
        'quota': 'Quota',
        'secure_only': 'bool',
        'complex_passwords': 'bool',
        'show_referral_links': 'bool',
        'external_domains': 'list[str]',
        'allowed_ip': 'list[AccountAttributesAllowedIp]',
        'callback_settings': 'CallbackSettings',
        'branding_settings': 'BrandingSettings',
        'client_id': 'int',
        'welcome_email_content': 'str',
        'welcome_email_subject': 'str',
        'custom_signature': 'str',
        'account_onboarding': 'bool',
        'created': 'datetime',
        'modified': 'datetime'
    }

    attribute_map = {
        'account_name': 'accountName',
        'username': 'username',
        'max_users': 'maxUsers',
        'user_count': 'userCount',
        'status': 'status',
        'branding': 'branding',
        'custom_domain': 'customDomain',
        'quota': 'quota',
        'secure_only': 'secureOnly',
        'complex_passwords': 'complexPasswords',
        'show_referral_links': 'showReferralLinks',
        'external_domains': 'externalDomains',
        'allowed_ip': 'allowedIp',
        'callback_settings': 'callbackSettings',
        'branding_settings': 'brandingSettings',
        'client_id': 'clientId',
        'welcome_email_content': 'welcomeEmailContent',
        'welcome_email_subject': 'welcomeEmailSubject',
        'custom_signature': 'customSignature',
        'account_onboarding': 'accountOnboarding',
        'created': 'created',
        'modified': 'modified'
    }

    def __init__(self, account_name=None, username=None, max_users=None, user_count=None, status=None, branding=None, custom_domain=None, quota=None, secure_only=None, complex_passwords=None, show_referral_links=None, external_domains=None, allowed_ip=None, callback_settings=None, branding_settings=None, client_id=None, welcome_email_content=None, welcome_email_subject=None, custom_signature=None, account_onboarding=None, created=None, modified=None):  # noqa: E501
        """AccountAttributes - a model defined in Swagger"""  # noqa: E501
        self._account_name = None
        self._username = None
        self._max_users = None
        self._user_count = None
        self._status = None
        self._branding = None
        self._custom_domain = None
        self._quota = None
        self._secure_only = None
        self._complex_passwords = None
        self._show_referral_links = None
        self._external_domains = None
        self._allowed_ip = None
        self._callback_settings = None
        self._branding_settings = None
        self._client_id = None
        self._welcome_email_content = None
        self._welcome_email_subject = None
        self._custom_signature = None
        self._account_onboarding = None
        self._created = None
        self._modified = None
        self.discriminator = None
        if account_name is not None:
            self.account_name = account_name
        if username is not None:
            self.username = username
        if max_users is not None:
            self.max_users = max_users
        if user_count is not None:
            self.user_count = user_count
        if status is not None:
            self.status = status
        if branding is not None:
            self.branding = branding
        if custom_domain is not None:
            self.custom_domain = custom_domain
        if quota is not None:
            self.quota = quota
        if secure_only is not None:
            self.secure_only = secure_only
        if complex_passwords is not None:
            self.complex_passwords = complex_passwords
        if show_referral_links is not None:
            self.show_referral_links = show_referral_links
        if external_domains is not None:
            self.external_domains = external_domains
        if allowed_ip is not None:
            self.allowed_ip = allowed_ip
        if callback_settings is not None:
            self.callback_settings = callback_settings
        if branding_settings is not None:
            self.branding_settings = branding_settings
        if client_id is not None:
            self.client_id = client_id
        if welcome_email_content is not None:
            self.welcome_email_content = welcome_email_content
        if welcome_email_subject is not None:
            self.welcome_email_subject = welcome_email_subject
        if custom_signature is not None:
            self.custom_signature = custom_signature
        if account_onboarding is not None:
            self.account_onboarding = account_onboarding
        if created is not None:
            self.created = created
        if modified is not None:
            self.modified = modified

    @property
    def account_name(self):
        """Gets the account_name of this AccountAttributes.  # noqa: E501

        Name of the account  # noqa: E501

        :return: The account_name of this AccountAttributes.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this AccountAttributes.

        Name of the account  # noqa: E501

        :param account_name: The account_name of this AccountAttributes.  # noqa: E501
        :type: str
        """

        self._account_name = account_name

    @property
    def username(self):
        """Gets the username of this AccountAttributes.  # noqa: E501

        Name of account's master user  # noqa: E501

        :return: The username of this AccountAttributes.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this AccountAttributes.

        Name of account's master user  # noqa: E501

        :param username: The username of this AccountAttributes.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def max_users(self):
        """Gets the max_users of this AccountAttributes.  # noqa: E501

        Maximum number of users the account can have. This can be increased by contacting ExaVault Support.  # noqa: E501

        :return: The max_users of this AccountAttributes.  # noqa: E501
        :rtype: int
        """
        return self._max_users

    @max_users.setter
    def max_users(self, max_users):
        """Sets the max_users of this AccountAttributes.

        Maximum number of users the account can have. This can be increased by contacting ExaVault Support.  # noqa: E501

        :param max_users: The max_users of this AccountAttributes.  # noqa: E501
        :type: int
        """

        self._max_users = max_users

    @property
    def user_count(self):
        """Gets the user_count of this AccountAttributes.  # noqa: E501

        Current number of users on the account.  # noqa: E501

        :return: The user_count of this AccountAttributes.  # noqa: E501
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """Sets the user_count of this AccountAttributes.

        Current number of users on the account.  # noqa: E501

        :param user_count: The user_count of this AccountAttributes.  # noqa: E501
        :type: int
        """

        self._user_count = user_count

    @property
    def status(self):
        """Gets the status of this AccountAttributes.  # noqa: E501

        Account status flag. A one (1) means the account is active; zero (0) means it is suspended.  # noqa: E501

        :return: The status of this AccountAttributes.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AccountAttributes.

        Account status flag. A one (1) means the account is active; zero (0) means it is suspended.  # noqa: E501

        :param status: The status of this AccountAttributes.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 0]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def branding(self):
        """Gets the branding of this AccountAttributes.  # noqa: E501

        Branding flag. Set to `true` if the account has branding functionality enabled.  # noqa: E501

        :return: The branding of this AccountAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._branding

    @branding.setter
    def branding(self, branding):
        """Sets the branding of this AccountAttributes.

        Branding flag. Set to `true` if the account has branding functionality enabled.  # noqa: E501

        :param branding: The branding of this AccountAttributes.  # noqa: E501
        :type: bool
        """

        self._branding = branding

    @property
    def custom_domain(self):
        """Gets the custom_domain of this AccountAttributes.  # noqa: E501

        Custom domain flag. Set to `true` if account type allows custom domain functionality.  # noqa: E501

        :return: The custom_domain of this AccountAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._custom_domain

    @custom_domain.setter
    def custom_domain(self, custom_domain):
        """Sets the custom_domain of this AccountAttributes.

        Custom domain flag. Set to `true` if account type allows custom domain functionality.  # noqa: E501

        :param custom_domain: The custom_domain of this AccountAttributes.  # noqa: E501
        :type: bool
        """

        self._custom_domain = custom_domain

    @property
    def quota(self):
        """Gets the quota of this AccountAttributes.  # noqa: E501


        :return: The quota of this AccountAttributes.  # noqa: E501
        :rtype: Quota
        """
        return self._quota

    @quota.setter
    def quota(self, quota):
        """Sets the quota of this AccountAttributes.


        :param quota: The quota of this AccountAttributes.  # noqa: E501
        :type: Quota
        """

        self._quota = quota

    @property
    def secure_only(self):
        """Gets the secure_only of this AccountAttributes.  # noqa: E501

        Flag to indicate whether the account disables connections via insecure protocols (e.g. FTP). Set to `true` to disable all traffic over port 21.  # noqa: E501

        :return: The secure_only of this AccountAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._secure_only

    @secure_only.setter
    def secure_only(self, secure_only):
        """Sets the secure_only of this AccountAttributes.

        Flag to indicate whether the account disables connections via insecure protocols (e.g. FTP). Set to `true` to disable all traffic over port 21.  # noqa: E501

        :param secure_only: The secure_only of this AccountAttributes.  # noqa: E501
        :type: bool
        """

        self._secure_only = secure_only

    @property
    def complex_passwords(self):
        """Gets the complex_passwords of this AccountAttributes.  # noqa: E501

        Flag to indicate whether the account requires complex passwords. Set to `true` to require complex passwords on all users and shares.  # noqa: E501

        :return: The complex_passwords of this AccountAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._complex_passwords

    @complex_passwords.setter
    def complex_passwords(self, complex_passwords):
        """Sets the complex_passwords of this AccountAttributes.

        Flag to indicate whether the account requires complex passwords. Set to `true` to require complex passwords on all users and shares.  # noqa: E501

        :param complex_passwords: The complex_passwords of this AccountAttributes.  # noqa: E501
        :type: bool
        """

        self._complex_passwords = complex_passwords

    @property
    def show_referral_links(self):
        """Gets the show_referral_links of this AccountAttributes.  # noqa: E501

        Flag to indicate showing of referrals links in the account. Set to `true` to include marketing messages in share invitations.  # noqa: E501

        :return: The show_referral_links of this AccountAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._show_referral_links

    @show_referral_links.setter
    def show_referral_links(self, show_referral_links):
        """Sets the show_referral_links of this AccountAttributes.

        Flag to indicate showing of referrals links in the account. Set to `true` to include marketing messages in share invitations.  # noqa: E501

        :param show_referral_links: The show_referral_links of this AccountAttributes.  # noqa: E501
        :type: bool
        """

        self._show_referral_links = show_referral_links

    @property
    def external_domains(self):
        """Gets the external_domains of this AccountAttributes.  # noqa: E501

        Custom domain used to brand this account.  # noqa: E501

        :return: The external_domains of this AccountAttributes.  # noqa: E501
        :rtype: list[str]
        """
        return self._external_domains

    @external_domains.setter
    def external_domains(self, external_domains):
        """Sets the external_domains of this AccountAttributes.

        Custom domain used to brand this account.  # noqa: E501

        :param external_domains: The external_domains of this AccountAttributes.  # noqa: E501
        :type: list[str]
        """

        self._external_domains = external_domains

    @property
    def allowed_ip(self):
        """Gets the allowed_ip of this AccountAttributes.  # noqa: E501

        Range of IP addresses allowed to access this account.  # noqa: E501

        :return: The allowed_ip of this AccountAttributes.  # noqa: E501
        :rtype: list[AccountAttributesAllowedIp]
        """
        return self._allowed_ip

    @allowed_ip.setter
    def allowed_ip(self, allowed_ip):
        """Sets the allowed_ip of this AccountAttributes.

        Range of IP addresses allowed to access this account.  # noqa: E501

        :param allowed_ip: The allowed_ip of this AccountAttributes.  # noqa: E501
        :type: list[AccountAttributesAllowedIp]
        """

        self._allowed_ip = allowed_ip

    @property
    def callback_settings(self):
        """Gets the callback_settings of this AccountAttributes.  # noqa: E501


        :return: The callback_settings of this AccountAttributes.  # noqa: E501
        :rtype: CallbackSettings
        """
        return self._callback_settings

    @callback_settings.setter
    def callback_settings(self, callback_settings):
        """Sets the callback_settings of this AccountAttributes.


        :param callback_settings: The callback_settings of this AccountAttributes.  # noqa: E501
        :type: CallbackSettings
        """

        self._callback_settings = callback_settings

    @property
    def branding_settings(self):
        """Gets the branding_settings of this AccountAttributes.  # noqa: E501


        :return: The branding_settings of this AccountAttributes.  # noqa: E501
        :rtype: BrandingSettings
        """
        return self._branding_settings

    @branding_settings.setter
    def branding_settings(self, branding_settings):
        """Sets the branding_settings of this AccountAttributes.


        :param branding_settings: The branding_settings of this AccountAttributes.  # noqa: E501
        :type: BrandingSettings
        """

        self._branding_settings = branding_settings

    @property
    def client_id(self):
        """Gets the client_id of this AccountAttributes.  # noqa: E501

        (ExaVault Use Only) Internal ID of the account in CMS.  # noqa: E501

        :return: The client_id of this AccountAttributes.  # noqa: E501
        :rtype: int
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this AccountAttributes.

        (ExaVault Use Only) Internal ID of the account in CMS.  # noqa: E501

        :param client_id: The client_id of this AccountAttributes.  # noqa: E501
        :type: int
        """

        self._client_id = client_id

    @property
    def welcome_email_content(self):
        """Gets the welcome_email_content of this AccountAttributes.  # noqa: E501

        Content of welcome email each new user will receive.  # noqa: E501

        :return: The welcome_email_content of this AccountAttributes.  # noqa: E501
        :rtype: str
        """
        return self._welcome_email_content

    @welcome_email_content.setter
    def welcome_email_content(self, welcome_email_content):
        """Sets the welcome_email_content of this AccountAttributes.

        Content of welcome email each new user will receive.  # noqa: E501

        :param welcome_email_content: The welcome_email_content of this AccountAttributes.  # noqa: E501
        :type: str
        """

        self._welcome_email_content = welcome_email_content

    @property
    def welcome_email_subject(self):
        """Gets the welcome_email_subject of this AccountAttributes.  # noqa: E501

        Subject of welcome email each new user will receive.  # noqa: E501

        :return: The welcome_email_subject of this AccountAttributes.  # noqa: E501
        :rtype: str
        """
        return self._welcome_email_subject

    @welcome_email_subject.setter
    def welcome_email_subject(self, welcome_email_subject):
        """Sets the welcome_email_subject of this AccountAttributes.

        Subject of welcome email each new user will receive.  # noqa: E501

        :param welcome_email_subject: The welcome_email_subject of this AccountAttributes.  # noqa: E501
        :type: str
        """

        self._welcome_email_subject = welcome_email_subject

    @property
    def custom_signature(self):
        """Gets the custom_signature of this AccountAttributes.  # noqa: E501

        Custom signature for all account emails users or recipients will receive.  # noqa: E501

        :return: The custom_signature of this AccountAttributes.  # noqa: E501
        :rtype: str
        """
        return self._custom_signature

    @custom_signature.setter
    def custom_signature(self, custom_signature):
        """Sets the custom_signature of this AccountAttributes.

        Custom signature for all account emails users or recipients will receive.  # noqa: E501

        :param custom_signature: The custom_signature of this AccountAttributes.  # noqa: E501
        :type: str
        """

        self._custom_signature = custom_signature

    @property
    def account_onboarding(self):
        """Gets the account_onboarding of this AccountAttributes.  # noqa: E501

        Whether the web application onboarding help is enabled for new users in the account.  # noqa: E501

        :return: The account_onboarding of this AccountAttributes.  # noqa: E501
        :rtype: bool
        """
        return self._account_onboarding

    @account_onboarding.setter
    def account_onboarding(self, account_onboarding):
        """Sets the account_onboarding of this AccountAttributes.

        Whether the web application onboarding help is enabled for new users in the account.  # noqa: E501

        :param account_onboarding: The account_onboarding of this AccountAttributes.  # noqa: E501
        :type: bool
        """

        self._account_onboarding = account_onboarding

    @property
    def created(self):
        """Gets the created of this AccountAttributes.  # noqa: E501

        Timestamp of account creation.  # noqa: E501

        :return: The created of this AccountAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this AccountAttributes.

        Timestamp of account creation.  # noqa: E501

        :param created: The created of this AccountAttributes.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def modified(self):
        """Gets the modified of this AccountAttributes.  # noqa: E501

        Timestamp of account modification.  # noqa: E501

        :return: The modified of this AccountAttributes.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this AccountAttributes.

        Timestamp of account modification.  # noqa: E501

        :param modified: The modified of this AccountAttributes.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountAttributes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ShareRelationships(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'messages': 'list[ShareRelationshipsMessage]',
        'owner': 'ShareRelationshipsOwner',
        'resources': 'list[ShareRelationshipsResource]',
        'notifications': 'list[ShareRelationshipsNotification]'
    }

    attribute_map = {
        'messages': 'messages',
        'owner': 'owner',
        'resources': 'resources',
        'notifications': 'notifications'
    }

    def __init__(self, messages=None, owner=None, resources=None, notifications=None):  # noqa: E501
        """ShareRelationships - a model defined in Swagger"""  # noqa: E501
        self._messages = None
        self._owner = None
        self._resources = None
        self._notifications = None
        self.discriminator = None
        if messages is not None:
            self.messages = messages
        if owner is not None:
            self.owner = owner
        if resources is not None:
            self.resources = resources
        if notifications is not None:
            self.notifications = notifications

    @property
    def messages(self):
        """Gets the messages of this ShareRelationships.  # noqa: E501

        null  # noqa: E501

        :return: The messages of this ShareRelationships.  # noqa: E501
        :rtype: list[ShareRelationshipsMessage]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """Sets the messages of this ShareRelationships.

        null  # noqa: E501

        :param messages: The messages of this ShareRelationships.  # noqa: E501
        :type: list[ShareRelationshipsMessage]
        """

        self._messages = messages

    @property
    def owner(self):
        """Gets the owner of this ShareRelationships.  # noqa: E501


        :return: The owner of this ShareRelationships.  # noqa: E501
        :rtype: ShareRelationshipsOwner
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this ShareRelationships.


        :param owner: The owner of this ShareRelationships.  # noqa: E501
        :type: ShareRelationshipsOwner
        """

        self._owner = owner

    @property
    def resources(self):
        """Gets the resources of this ShareRelationships.  # noqa: E501


        :return: The resources of this ShareRelationships.  # noqa: E501
        :rtype: list[ShareRelationshipsResource]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this ShareRelationships.


        :param resources: The resources of this ShareRelationships.  # noqa: E501
        :type: list[ShareRelationshipsResource]
        """

        self._resources = resources

    @property
    def notifications(self):
        """Gets the notifications of this ShareRelationships.  # noqa: E501

        null  # noqa: E501

        :return: The notifications of this ShareRelationships.  # noqa: E501
        :rtype: list[ShareRelationshipsNotification]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """Sets the notifications of this ShareRelationships.

        null  # noqa: E501

        :param notifications: The notifications of this ShareRelationships.  # noqa: E501
        :type: list[ShareRelationshipsNotification]
        """

        self._notifications = notifications

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ShareRelationships, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShareRelationships):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CompressFilesRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resources': 'list[str]',
        'parent_resource': 'str',
        'archive_name': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'parent_resource': 'parentResource',
        'archive_name': 'archiveName'
    }

    def __init__(self, resources=None, parent_resource=None, archive_name=None):  # noqa: E501
        """CompressFilesRequestBody - a model defined in Swagger"""  # noqa: E501
        self._resources = None
        self._parent_resource = None
        self._archive_name = None
        self.discriminator = None
        self.resources = resources
        if parent_resource is not None:
            self.parent_resource = parent_resource
        if archive_name is not None:
            self.archive_name = archive_name

    @property
    def resources(self):
        """Gets the resources of this CompressFilesRequestBody.  # noqa: E501

        Resource identifiers for file(s)/folder(s) to include in new zip file  # noqa: E501

        :return: The resources of this CompressFilesRequestBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this CompressFilesRequestBody.

        Resource identifiers for file(s)/folder(s) to include in new zip file  # noqa: E501

        :param resources: The resources of this CompressFilesRequestBody.  # noqa: E501
        :type: list[str]
        """
        if resources is None:
            raise ValueError("Invalid value for `resources`, must not be `None`")  # noqa: E501

        self._resources = resources

    @property
    def parent_resource(self):
        """Gets the parent_resource of this CompressFilesRequestBody.  # noqa: E501

        Resource identifier of the folder where zip archive should be created.  # noqa: E501

        :return: The parent_resource of this CompressFilesRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._parent_resource

    @parent_resource.setter
    def parent_resource(self, parent_resource):
        """Sets the parent_resource of this CompressFilesRequestBody.

        Resource identifier of the folder where zip archive should be created.  # noqa: E501

        :param parent_resource: The parent_resource of this CompressFilesRequestBody.  # noqa: E501
        :type: str
        """

        self._parent_resource = parent_resource

    @property
    def archive_name(self):
        """Gets the archive_name of this CompressFilesRequestBody.  # noqa: E501

        Name of the zip archive to create. If left blank, current date will be used.  # noqa: E501

        :return: The archive_name of this CompressFilesRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._archive_name

    @archive_name.setter
    def archive_name(self, archive_name):
        """Sets the archive_name of this CompressFilesRequestBody.

        Name of the zip archive to create. If left blank, current date will be used.  # noqa: E501

        :param archive_name: The archive_name of this CompressFilesRequestBody.  # noqa: E501
        :type: str
        """

        self._archive_name = archive_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CompressFilesRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompressFilesRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FormFieldSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'width': 'float',
        'is_required': 'bool',
        'use_as_folder_name': 'bool',
        'sender_email': 'bool'
    }

    attribute_map = {
        'description': 'description',
        'width': 'width',
        'is_required': 'isRequired',
        'use_as_folder_name': 'useAsFolderName',
        'sender_email': 'senderEmail'
    }

    def __init__(self, description=None, width=None, is_required=None, use_as_folder_name=None, sender_email=None):  # noqa: E501
        """FormFieldSettings - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._width = None
        self._is_required = None
        self._use_as_folder_name = None
        self._sender_email = None
        self.discriminator = None
        if description is not None:
            self.description = description
        if width is not None:
            self.width = width
        if is_required is not None:
            self.is_required = is_required
        if use_as_folder_name is not None:
            self.use_as_folder_name = use_as_folder_name
        if sender_email is not None:
            self.sender_email = sender_email

    @property
    def description(self):
        """Gets the description of this FormFieldSettings.  # noqa: E501

        Secondary description of field.  # noqa: E501

        :return: The description of this FormFieldSettings.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this FormFieldSettings.

        Secondary description of field.  # noqa: E501

        :param description: The description of this FormFieldSettings.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def width(self):
        """Gets the width of this FormFieldSettings.  # noqa: E501

        How much of the available width the field should occupy  # noqa: E501

        :return: The width of this FormFieldSettings.  # noqa: E501
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this FormFieldSettings.

        How much of the available width the field should occupy  # noqa: E501

        :param width: The width of this FormFieldSettings.  # noqa: E501
        :type: float
        """

        self._width = width

    @property
    def is_required(self):
        """Gets the is_required of this FormFieldSettings.  # noqa: E501

        Whether this field must be completed before form can be submitted  # noqa: E501

        :return: The is_required of this FormFieldSettings.  # noqa: E501
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """Sets the is_required of this FormFieldSettings.

        Whether this field must be completed before form can be submitted  # noqa: E501

        :param is_required: The is_required of this FormFieldSettings.  # noqa: E501
        :type: bool
        """

        self._is_required = is_required

    @property
    def use_as_folder_name(self):
        """Gets the use_as_folder_name of this FormFieldSettings.  # noqa: E501

        Whether to place submitted files into a subfolder named the contents of this field. Only takes effect when the `fileDropCreateFolders` parameter on the receive folder is `true`. `isRequired` must be set to `true` if this setting is `true`.  # noqa: E501

        :return: The use_as_folder_name of this FormFieldSettings.  # noqa: E501
        :rtype: bool
        """
        return self._use_as_folder_name

    @use_as_folder_name.setter
    def use_as_folder_name(self, use_as_folder_name):
        """Sets the use_as_folder_name of this FormFieldSettings.

        Whether to place submitted files into a subfolder named the contents of this field. Only takes effect when the `fileDropCreateFolders` parameter on the receive folder is `true`. `isRequired` must be set to `true` if this setting is `true`.  # noqa: E501

        :param use_as_folder_name: The use_as_folder_name of this FormFieldSettings.  # noqa: E501
        :type: bool
        """

        self._use_as_folder_name = use_as_folder_name

    @property
    def sender_email(self):
        """Gets the sender_email of this FormFieldSettings.  # noqa: E501


        :return: The sender_email of this FormFieldSettings.  # noqa: E501
        :rtype: bool
        """
        return self._sender_email

    @sender_email.setter
    def sender_email(self, sender_email):
        """Sets the sender_email of this FormFieldSettings.


        :param sender_email: The sender_email of this FormFieldSettings.  # noqa: E501
        :type: bool
        """

        self._sender_email = sender_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FormFieldSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormFieldSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Quota(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'disk_limit': 'int',
        'disk_used': 'int',
        'notice_enabled': 'bool',
        'notice_threshold': 'int'
    }

    attribute_map = {
        'disk_limit': 'diskLimit',
        'disk_used': 'diskUsed',
        'notice_enabled': 'noticeEnabled',
        'notice_threshold': 'noticeThreshold'
    }

    def __init__(self, disk_limit=None, disk_used=None, notice_enabled=None, notice_threshold=None):  # noqa: E501
        """Quota - a model defined in Swagger"""  # noqa: E501
        self._disk_limit = None
        self._disk_used = None
        self._notice_enabled = None
        self._notice_threshold = None
        self.discriminator = None
        if disk_limit is not None:
            self.disk_limit = disk_limit
        if disk_used is not None:
            self.disk_used = disk_used
        if notice_enabled is not None:
            self.notice_enabled = notice_enabled
        if notice_threshold is not None:
            self.notice_threshold = notice_threshold

    @property
    def disk_limit(self):
        """Gets the disk_limit of this Quota.  # noqa: E501

        Amount of disk space that the account has available to it. This may be increased by upgrading to a larger plan.  # noqa: E501

        :return: The disk_limit of this Quota.  # noqa: E501
        :rtype: int
        """
        return self._disk_limit

    @disk_limit.setter
    def disk_limit(self, disk_limit):
        """Sets the disk_limit of this Quota.

        Amount of disk space that the account has available to it. This may be increased by upgrading to a larger plan.  # noqa: E501

        :param disk_limit: The disk_limit of this Quota.  # noqa: E501
        :type: int
        """

        self._disk_limit = disk_limit

    @property
    def disk_used(self):
        """Gets the disk_used of this Quota.  # noqa: E501

        Amount of disk space currently in use.  # noqa: E501

        :return: The disk_used of this Quota.  # noqa: E501
        :rtype: int
        """
        return self._disk_used

    @disk_used.setter
    def disk_used(self, disk_used):
        """Sets the disk_used of this Quota.

        Amount of disk space currently in use.  # noqa: E501

        :param disk_used: The disk_used of this Quota.  # noqa: E501
        :type: int
        """

        self._disk_used = disk_used

    @property
    def notice_enabled(self):
        """Gets the notice_enabled of this Quota.  # noqa: E501

        Should a quota warning be sent to the account owner when a threshold level of space utilization is reached?  # noqa: E501

        :return: The notice_enabled of this Quota.  # noqa: E501
        :rtype: bool
        """
        return self._notice_enabled

    @notice_enabled.setter
    def notice_enabled(self, notice_enabled):
        """Sets the notice_enabled of this Quota.

        Should a quota warning be sent to the account owner when a threshold level of space utilization is reached?  # noqa: E501

        :param notice_enabled: The notice_enabled of this Quota.  # noqa: E501
        :type: bool
        """

        self._notice_enabled = notice_enabled

    @property
    def notice_threshold(self):
        """Gets the notice_threshold of this Quota.  # noqa: E501

        Treshold that triggers a quota notification. This represents the \"percent full\" your account must be before the quota notification is generated.  # noqa: E501

        :return: The notice_threshold of this Quota.  # noqa: E501
        :rtype: int
        """
        return self._notice_threshold

    @notice_threshold.setter
    def notice_threshold(self, notice_threshold):
        """Sets the notice_threshold of this Quota.

        Treshold that triggers a quota notification. This represents the \"percent full\" your account must be before the quota notification is generated.  # noqa: E501

        :param notice_threshold: The notice_threshold of this Quota.  # noqa: E501
        :type: int
        """

        self._notice_threshold = notice_threshold

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Quota, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Quota):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    ExaVault API

    See our API reference documentation at https://www.exavault.com/developer/api-docs/  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@exavault.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UpdateAccountRequestBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'quota_notice_enabled': 'bool',
        'quota_notice_threshold': 'int',
        'secure_only': 'bool',
        'complex_passwords': 'bool',
        'show_referral_links': 'bool',
        'external_domain': 'str',
        'email_content': 'str',
        'email_subject': 'str',
        'allowed_ip_ranges': 'list[AccountAllowedIpRanges]',
        'callback_settings': 'CallbackSettingsValues',
        'branding_settings': 'BrandingSettingsValues',
        'account_onboarding': 'bool',
        'custom_signature': 'str'
    }

    attribute_map = {
        'quota_notice_enabled': 'quotaNoticeEnabled',
        'quota_notice_threshold': 'quotaNoticeThreshold',
        'secure_only': 'secureOnly',
        'complex_passwords': 'complexPasswords',
        'show_referral_links': 'showReferralLinks',
        'external_domain': 'externalDomain',
        'email_content': 'emailContent',
        'email_subject': 'emailSubject',
        'allowed_ip_ranges': 'allowedIpRanges',
        'callback_settings': 'callbackSettings',
        'branding_settings': 'brandingSettings',
        'account_onboarding': 'accountOnboarding',
        'custom_signature': 'customSignature'
    }

    def __init__(self, quota_notice_enabled=None, quota_notice_threshold=None, secure_only=None, complex_passwords=None, show_referral_links=None, external_domain=None, email_content=None, email_subject=None, allowed_ip_ranges=None, callback_settings=None, branding_settings=None, account_onboarding=None, custom_signature=None):  # noqa: E501
        """UpdateAccountRequestBody - a model defined in Swagger"""  # noqa: E501
        self._quota_notice_enabled = None
        self._quota_notice_threshold = None
        self._secure_only = None
        self._complex_passwords = None
        self._show_referral_links = None
        self._external_domain = None
        self._email_content = None
        self._email_subject = None
        self._allowed_ip_ranges = None
        self._callback_settings = None
        self._branding_settings = None
        self._account_onboarding = None
        self._custom_signature = None
        self.discriminator = None
        if quota_notice_enabled is not None:
            self.quota_notice_enabled = quota_notice_enabled
        if quota_notice_threshold is not None:
            self.quota_notice_threshold = quota_notice_threshold
        if secure_only is not None:
            self.secure_only = secure_only
        if complex_passwords is not None:
            self.complex_passwords = complex_passwords
        if show_referral_links is not None:
            self.show_referral_links = show_referral_links
        if external_domain is not None:
            self.external_domain = external_domain
        if email_content is not None:
            self.email_content = email_content
        if email_subject is not None:
            self.email_subject = email_subject
        if allowed_ip_ranges is not None:
            self.allowed_ip_ranges = allowed_ip_ranges
        if callback_settings is not None:
            self.callback_settings = callback_settings
        if branding_settings is not None:
            self.branding_settings = branding_settings
        if account_onboarding is not None:
            self.account_onboarding = account_onboarding
        if custom_signature is not None:
            self.custom_signature = custom_signature

    @property
    def quota_notice_enabled(self):
        """Gets the quota_notice_enabled of this UpdateAccountRequestBody.  # noqa: E501

        Whether the system should email the account owner when usage exceeds quotaNoticeThreshold value  # noqa: E501

        :return: The quota_notice_enabled of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._quota_notice_enabled

    @quota_notice_enabled.setter
    def quota_notice_enabled(self, quota_notice_enabled):
        """Sets the quota_notice_enabled of this UpdateAccountRequestBody.

        Whether the system should email the account owner when usage exceeds quotaNoticeThreshold value  # noqa: E501

        :param quota_notice_enabled: The quota_notice_enabled of this UpdateAccountRequestBody.  # noqa: E501
        :type: bool
        """

        self._quota_notice_enabled = quota_notice_enabled

    @property
    def quota_notice_threshold(self):
        """Gets the quota_notice_threshold of this UpdateAccountRequestBody.  # noqa: E501

        Percent of account usage to trigger quota notices for.  # noqa: E501

        :return: The quota_notice_threshold of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: int
        """
        return self._quota_notice_threshold

    @quota_notice_threshold.setter
    def quota_notice_threshold(self, quota_notice_threshold):
        """Sets the quota_notice_threshold of this UpdateAccountRequestBody.

        Percent of account usage to trigger quota notices for.  # noqa: E501

        :param quota_notice_threshold: The quota_notice_threshold of this UpdateAccountRequestBody.  # noqa: E501
        :type: int
        """

        self._quota_notice_threshold = quota_notice_threshold

    @property
    def secure_only(self):
        """Gets the secure_only of this UpdateAccountRequestBody.  # noqa: E501

        Whether unencrypted FTP connections should be denied for the account.  # noqa: E501

        :return: The secure_only of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._secure_only

    @secure_only.setter
    def secure_only(self, secure_only):
        """Sets the secure_only of this UpdateAccountRequestBody.

        Whether unencrypted FTP connections should be denied for the account.  # noqa: E501

        :param secure_only: The secure_only of this UpdateAccountRequestBody.  # noqa: E501
        :type: bool
        """

        self._secure_only = secure_only

    @property
    def complex_passwords(self):
        """Gets the complex_passwords of this UpdateAccountRequestBody.  # noqa: E501

        Whether to require complex passwords for all passwords.  # noqa: E501

        :return: The complex_passwords of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._complex_passwords

    @complex_passwords.setter
    def complex_passwords(self, complex_passwords):
        """Sets the complex_passwords of this UpdateAccountRequestBody.

        Whether to require complex passwords for all passwords.  # noqa: E501

        :param complex_passwords: The complex_passwords of this UpdateAccountRequestBody.  # noqa: E501
        :type: bool
        """

        self._complex_passwords = complex_passwords

    @property
    def show_referral_links(self):
        """Gets the show_referral_links of this UpdateAccountRequestBody.  # noqa: E501

        Whether to display links for others to sign up on share views and invitation emails  # noqa: E501

        :return: The show_referral_links of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._show_referral_links

    @show_referral_links.setter
    def show_referral_links(self, show_referral_links):
        """Sets the show_referral_links of this UpdateAccountRequestBody.

        Whether to display links for others to sign up on share views and invitation emails  # noqa: E501

        :param show_referral_links: The show_referral_links of this UpdateAccountRequestBody.  # noqa: E501
        :type: bool
        """

        self._show_referral_links = show_referral_links

    @property
    def external_domain(self):
        """Gets the external_domain of this UpdateAccountRequestBody.  # noqa: E501

        Custom address used for web file manager. Not available for all account types.  # noqa: E501

        :return: The external_domain of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._external_domain

    @external_domain.setter
    def external_domain(self, external_domain):
        """Sets the external_domain of this UpdateAccountRequestBody.

        Custom address used for web file manager. Not available for all account types.  # noqa: E501

        :param external_domain: The external_domain of this UpdateAccountRequestBody.  # noqa: E501
        :type: str
        """

        self._external_domain = external_domain

    @property
    def email_content(self):
        """Gets the email_content of this UpdateAccountRequestBody.  # noqa: E501

        Content of welcome email template.  # noqa: E501

        :return: The email_content of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._email_content

    @email_content.setter
    def email_content(self, email_content):
        """Sets the email_content of this UpdateAccountRequestBody.

        Content of welcome email template.  # noqa: E501

        :param email_content: The email_content of this UpdateAccountRequestBody.  # noqa: E501
        :type: str
        """

        self._email_content = email_content

    @property
    def email_subject(self):
        """Gets the email_subject of this UpdateAccountRequestBody.  # noqa: E501

        Subject line for welcome emails  # noqa: E501

        :return: The email_subject of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._email_subject

    @email_subject.setter
    def email_subject(self, email_subject):
        """Sets the email_subject of this UpdateAccountRequestBody.

        Subject line for welcome emails  # noqa: E501

        :param email_subject: The email_subject of this UpdateAccountRequestBody.  # noqa: E501
        :type: str
        """

        self._email_subject = email_subject

    @property
    def allowed_ip_ranges(self):
        """Gets the allowed_ip_ranges of this UpdateAccountRequestBody.  # noqa: E501

        IP Address Ranges for restricting account access  # noqa: E501

        :return: The allowed_ip_ranges of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: list[AccountAllowedIpRanges]
        """
        return self._allowed_ip_ranges

    @allowed_ip_ranges.setter
    def allowed_ip_ranges(self, allowed_ip_ranges):
        """Sets the allowed_ip_ranges of this UpdateAccountRequestBody.

        IP Address Ranges for restricting account access  # noqa: E501

        :param allowed_ip_ranges: The allowed_ip_ranges of this UpdateAccountRequestBody.  # noqa: E501
        :type: list[AccountAllowedIpRanges]
        """

        self._allowed_ip_ranges = allowed_ip_ranges

    @property
    def callback_settings(self):
        """Gets the callback_settings of this UpdateAccountRequestBody.  # noqa: E501


        :return: The callback_settings of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: CallbackSettingsValues
        """
        return self._callback_settings

    @callback_settings.setter
    def callback_settings(self, callback_settings):
        """Sets the callback_settings of this UpdateAccountRequestBody.


        :param callback_settings: The callback_settings of this UpdateAccountRequestBody.  # noqa: E501
        :type: CallbackSettingsValues
        """

        self._callback_settings = callback_settings

    @property
    def branding_settings(self):
        """Gets the branding_settings of this UpdateAccountRequestBody.  # noqa: E501


        :return: The branding_settings of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: BrandingSettingsValues
        """
        return self._branding_settings

    @branding_settings.setter
    def branding_settings(self, branding_settings):
        """Sets the branding_settings of this UpdateAccountRequestBody.


        :param branding_settings: The branding_settings of this UpdateAccountRequestBody.  # noqa: E501
        :type: BrandingSettingsValues
        """

        self._branding_settings = branding_settings

    @property
    def account_onboarding(self):
        """Gets the account_onboarding of this UpdateAccountRequestBody.  # noqa: E501

        Whether extra help popups can be enabled for users in the web file manager.  # noqa: E501

        :return: The account_onboarding of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: bool
        """
        return self._account_onboarding

    @account_onboarding.setter
    def account_onboarding(self, account_onboarding):
        """Sets the account_onboarding of this UpdateAccountRequestBody.

        Whether extra help popups can be enabled for users in the web file manager.  # noqa: E501

        :param account_onboarding: The account_onboarding of this UpdateAccountRequestBody.  # noqa: E501
        :type: bool
        """

        self._account_onboarding = account_onboarding

    @property
    def custom_signature(self):
        """Gets the custom_signature of this UpdateAccountRequestBody.  # noqa: E501

        Signature to be automatically added to the bottom of emails generated by the account.  # noqa: E501

        :return: The custom_signature of this UpdateAccountRequestBody.  # noqa: E501
        :rtype: str
        """
        return self._custom_signature

    @custom_signature.setter
    def custom_signature(self, custom_signature):
        """Sets the custom_signature of this UpdateAccountRequestBody.

        Signature to be automatically added to the bottom of emails generated by the account.  # noqa: E501

        :param custom_signature: The custom_signature of this UpdateAccountRequestBody.  # noqa: E501
        :type: str
        """

        self._custom_signature = custom_signature

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateAccountRequestBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAccountRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
